"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRandomValues = void 0;
function getRandomBytes(numBytes) {
    return crypto.getRandomValues(new Uint8Array(numBytes));
}
function getRandomByte() {
    return getRandomBytes(1)[0];
}
function getRandomValueInRange(start, until) {
    if (start < 0) {
        throw new Error('Invalid byte range: range start must be at least 0');
    }
    if (until - start < 2) {
        throw new Error('Invalid byte range: range must contain at least two values');
    }
    if (until > 256) {
        throw new Error('Invalid byte range: range until must be at most 256');
    }
    const rangeSize = until - start;
    const byteRangeMax = rangeSize * Math.floor(256 / rangeSize);
    while (true) {
        const byte = getRandomByte();
        if (byte < byteRangeMax) {
            return start + (byte % rangeSize);
        }
    }
}
function getRandomValues(numBytes, rangeMax = 256) {
    if (numBytes < 0) {
        throw new Error('Invalid number of bytes: number of bytes to return must be at least 0');
    }
    if (numBytes === 0) {
        return new Uint8Array(0);
    }
    if (rangeMax === 256) {
        return getRandomBytes(numBytes);
    }
    const bytes = new Uint8Array(numBytes);
    for (let i = 0; i < numBytes; i++) {
        bytes[i] = getRandomValueInRange(0, rangeMax);
    }
    return bytes;
}
exports.getRandomValues = getRandomValues;
